@@ -2,8 +2,7 @@
 from __future__ import annotations
 
 import ctypes
-# noinspection PyUnresolvedReferences, PyProtectedMember
-from ctypes import pointer, _Pointer, Array
+from ctypes import Array
 from string import Template
 from typing import TYPE_CHECKING, Any
 
@@ -22,25 +21,37 @@ DISP_TRANSFORMS = {
 }
 
 
-def format_value(obj: Any, cast_to: type | None = None) -> str:
-    """Format a value."""
+def format_value(
+    obj: Any, cast_to: type | None = None, arr_bound: int | None = None
+) -> str:
+    """
+    Format a value.
+
+    Args:
+        obj: The value to format
+        cast_to: The type to cast the value to
+        arr_bound: The max number of pointers to dereference for Array[PyObject] types
+    """
     # Cast if needed
     if cast_to is not None:
         obj = ctypes.cast(obj, cast_to)  # type: ignore
         return format_value(obj)
     # Array: format as list
     if isinstance(obj, Array):
-        res = list(map(format_value, obj))
-        return f"[{', '.join(res)}]"
+        # Only get elements up to arr_bound
+        res = list(map(format_value, obj[:arr_bound]))
+        diff = len(obj) - len(res)
+        return f"[{', '.join(res)}{', ...' if diff > 0 else ''}]"
     # For pointers, get the value
-    if isinstance(obj, _Pointer):
+    # noinspection PyUnresolvedReferences, PyProtectedMember
+    if isinstance(obj, ctypes._Pointer):
         val = format_value(obj.contents) if obj else "NULL"
         wrap = f"[{val}]" if not (val.startswith("[") and val.endswith("]")) else val
         return f"&{wrap}"
     # For PyObject, get the object
     if isinstance(obj, PyObject):
         obj.IncRef()
-        return format_value(obj.into_object().value)
+        return format_value(obj.into_object())
     # Other cases
     try:
         return DISP_TRANSFORMS[type(obj)](obj)
@@ -48,7 +59,9 @@ def format_value(obj: Any, cast_to: type | None = None) -> str:
         return repr(obj)
 
 
-def format_attr(struct: PyObject, attr: str, hint: str | tuple[str, type], types: bool) -> str:
+def format_attr(
+    struct: PyObject, attr: str, hint: str | tuple[str, type], types: bool
+) -> str:
     value = getattr(struct, attr)
     type_cast = None
     if isinstance(hint, tuple):
@@ -75,8 +88,6 @@ def format_display(v: View, types: bool = True) -> str:
 
     # Get attributes
     for attr, type_hint in struct._format_fields_().items():
-        lines.append(
-            indent(format_attr(struct, attr, type_hint, types))
-        )
+        lines.append(indent(format_attr(struct, attr, type_hint, types)))
 
     return "\n".join(lines)
